modems = {
    "2c7c": { # Quectel VENDOR_ID
        "EC25": { # Modem Name
            "0125": ["02"] # USB_COMPOSITION_ID
        },
        "EC21": { # Modem Name
            "0121": ["02"] # USB_COMPOSITION_ID
        },
        "BG96": { # Modem Name
            "0296": ["02"] # USB_COMPOSITION_ID
        },
        "BG95": { # Modem Name
            "0700": ["02"] # USB_COMPOSITION_ID
        }
    },
    "1bc7": { # Telit VENDOR_ID
        "LE910": { # Modem Name
            "1201": ["04"], # USB_COMPOSITION_ID
            "1206": ["05"] # USB_COMPOSITION_ID
        },
        "ME910": {
            "1101": ["01"]
        }
    }
}
